Learn R Programming

geocausal (version 0.4.0)

get_cf_dens_adaptive: Get counterfactual densities

Description

`get_cf_dens_adaptive` takes the scale_factor, baseline density to construct counterfactural intensities .

Usage

get_cf_dens_adaptive(baseline_den, scale_factor)

Value

a list of the following: * `intens_grid_cells`: im object of counterfactural intensities for each time period * `estimated_counts`: the number of events that is estimated by the poisson point process model for each time period * `sum_log_intens`: the sum of log intensities for each time period

Arguments

baseline_den

baseline density (obs object obtained from `get_adaptive_baseline_dens`)

scale_factor

a positive number that scales the baseline intensity